/*
 *  Eukleides version 1.5.4
 *  Copyright (c) Christian Obrecht 2004-2010
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

int preamble;

void put_preamble(_param p);

void put_closing(_param p);

void draw_point(_param p);

void draw_vector(_param p);

void draw_path(_param p);

void draw_polygon(_param p);

void fill_polygon(_param p);

void hatch_polygon(_param p);

void draw_line(_param p);

void draw_circle(_param p);

void draw_arc(_param p);

void fill_circle(_param p);

void hatch_circle(_param p);

void draw_conic(_param p);

void draw_conic_arc(_param p);

void draw_string(_param p);

void label_segment(_param p);

void label_angle(_param p);

void label_point(_param p);
